==> react-ui-library-6.0.0.tgz: package/src/components/theme.js <==
import Color from 'color'

const rawColors = {
  green900: '#21523A',
  green800: '#2B6B4C',
  green700: '#35855E',
  green600: '#3F9E70',
  green500: '#49B882',
  green400: '#54D194',
  green300: '#84DBB1',
  green200: '#A8F0CD',
  green100: '#CCFFE6',
  green50: '#e4f7ed',

  blue900: '#0A2A48',
  blue800: '#004585',
  blue700: '#00529E',
  blue600: '#005FB8',
  blue500: '#006CD1',
  blue400: '#1785EB',
  blue300: '#5EA7EB',
  blue200: '#99CEFF',
  blue100: '#C7E4FF',
  blue50: '#EAF3FB',

  peach500: '#FCC79B',
  peach400: '#FAE0CB',
  peach50: '#FCF1E8',

  pink500: '#E365A6',
  pink400: '#FFDAED',
  pink50: '#FAEFF5',

  grey500: '#193652',
  grey400: '#3D556B',
  grey300: '#8FA1B3',
  grey200: '#D9E3ED',
  grey100: '#F2F5F7',
  grey50: '#F9FAFB',

  white: '#FFFFFF'
}

const textColors = {
  title: rawColors.grey500,
  body: rawColors.grey400,
  muted: rawColors.grey300,
  white: rawColors.white
}

const colors = {
  primary: rawColors.green500,
  dark: rawColors.blue900,
  borderColor: rawColors.grey200,
  activeColor: rawColors.blue500,

  backgroundTint1: rawColors.grey50,
  backgroundTint2: rawColors.grey100,

  white: rawColors.white,

  danger: rawColors.pink500,
  success: rawColors.green500,
  question: rawColors.blue500,
  warning: rawColors.peach500
}

const majorScale = x => `${x * 8}px`
const minorScale = x => `${x * 4}px`

/**
 * Preset sizes for input and button elements
 */

const controlSizes = {
  default: {
    minHeight: majorScale(4),
    minWidth: majorScale(4),
    textStyle: 'body2'
  },
  large: {
    minHeight: majorScale(5),
    minWidth: majorScale(5),
    textStyle: 'body1'
  }
}

const fonts = {}

fonts.sans = `'Segment Circular Std', 'Helvetica Neue', Helvetica, Arial, sans-serif`
fonts.serif = `'Segment Aleo', Georgia, serif`
fonts.mono = `'Droid Sans Mono', Monaco, 'Lucida Console', monospace`

const textStyles = {}

textStyles.display1 = {
  fontFamily: fonts.sans,
  fontSize: '22px',
  fontWeight: '400',
  lineHeight: majorScale(4),
  letterSpacing: '-0.67px'
}

textStyles.display2 = {
  fontFamily: fonts.sans,
  fontSize: '20px',
  fontWeight: '400',
  lineHeight: majorScale(4),
  letterSpacing: '-0.645px'
}

textStyles.display3 = {
  fontFamily: fonts.sans,
  fontSize: '18px',
  fontWeight: '400',
  lineHeight: majorScale(3),
  letterSpacing: '-0.31px'
}

textStyles.display4 = {
  fontFamily: fonts.sans,
  fontSize: '16px',
  fontWeight: '500',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.display5 = {
  fontFamily: fonts.sans,
  fontSize: '14px',
  fontWeight: '500',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.body1 = {
  // color: textColors.body,
  fontFamily: fonts.sans,
  fontSize: '14px',
  fontWeight: '400',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.body2 = {
  fontFamily: fonts.sans,
  fontSize: '12px',
  fontWeight: '400',
  lineHeight: majorScale(2),
  letterSpacing: '0'
}

textStyles.mono = {
  fontFamily: fonts.mono,
  fontSize: '13px',
  fontWeight: '300',
  lineHeight: '21px',
  letterSpacing: '0'
}

textStyles.caps1 = {
  fontFamily: fonts.sans,
  fontSize: '12px',
  fontWeight: '500',
  lineHeight: majorScale(2),
  letterSpacing: '0.08em',
  textTransform: 'uppercase'
}

textStyles.caps2 = {
  fontFamily: fonts.sans,
  fontSize: '10px',
  fontWeight: '600',
  lineHeight: majorScale(2),
  letterSpacing: '0.08em',
  textTransform: 'uppercase'
}

const intent = {
  primary: {
    default: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    hover: {
      linkColor: Color(colors.primary).lighten(0.2).saturate(0.2).rgb().string(),
      backgroundColor: rawColors.green400,
      textColor: colors.white
    },
    active: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    focus: {
      linkColor: colors.primary,
      backgroundColor: rawColors.green400,
      textColor: colors.white
    }
  },
  secondary: {
    default: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      boxShadow: `inset 0 0 0 1px ${colors.borderColor}`
    },
    hover: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      boxShadow: `inset 0 0 0 1px ${colors.primary}`
    },
    active: {
      linkColor: colors.activeColor,
      backgroundColor: colors.backgroundTint1,
      textColor: textColors.title,
      boxShadow: `inset 0 0 0 1px ${colors.primary}`
    },
    focus: {
      linkColor: colors.darkTint,
      backgroundColor: colors.white,
      textColor: textColors.body,
      boxShadow: `inset 0 0 0 1px ${colors.prmary}`
    }
  },
  danger: {
    default: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: colors.white
    },
    hover: {
      linkColor: colors.danger,
      backgroundColor: Color(colors.danger).whiten(0.3).rgb().string(),
      textColor: textColors.white
    },
    active: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: textColors.white
    },
    focus: {
      linkColor: colors.danger,
      backgroundColor: [Color(colors.danger).whiten(0.3).rgb().string()],
      textColor: textColors.white
    }
  }
}

const backgrounds = {}

backgrounds.dark = {
  textColor: colors.white,
  backgroundColor: colors.dark,
  borderColor: colors.borderColor, // TODO: implement/think about dark borderColor
  borderColorInteractive: colors.borderColor
}

backgrounds.white = {
  textColor: textColors.body,
  backgroundColor: colors.white,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

backgrounds.tint1 = backgrounds.tint = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey50,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

backgrounds.tint2 = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey100,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

const animationEasing = {
  standard: `cubic-bezier(0.4, 0.0, 0.2, 1)`,
  deceleration: `cubic-bezier(0.0, 0.0, 0.2, 1)`,
  acceleration: `cubic-bezier(0.4, 0.0, 1, 1)`,
  sharp: `cubic-bezier(0.4, 0.0, 0.6, 1)`,
  spring: `cubic-bezier(0.175, 0.885, 0.320, 1.175)`
}

// https://material.io/guidelines/motion/duration-easing.html#duration-easing-common-durations
const animationDuration = {
  faster: `150ms`,
  fast: `225ms`,
  slow: `400ms`
}

const activeClassName = 'evergreen-active'

const theme = {
  activeClassName,
  majorScale,
  minorScale,
  animationEasing,
  animationDuration,
  rawColors,
  backgrounds,
  fonts,
  textColors,
  textStyles,
  colors,
  intent,
  controlSizes,
  borderRadius: ['5px', '8px'],
  popoverShadow: `0 2px 4px rgba(0,0,0,0.04), 0 8px 24px rgba(0,0,0,0.02)`,
  shadows: [
    '0 5px 15px -5px rgba(0,0,0,0.1)',
    '0 2px 4px 0 rgba(0,0,0,0.04)'
  ]
}

export default theme

==> react-ui-library-7.0.0.tgz: package/src/components/theme.js <==
import Color from 'color'

const rawColors = {
  green900: '#21523A',
  green800: '#2B6B4C',
  green700: '#35855E',
  green600: '#3F9E70',
  green500: '#49B882',
  green400: '#54D194',
  green300: '#84DBB1',
  green200: '#A8F0CD',
  green100: '#CCFFE6',
  green50: '#e4f7ed',

  blue900: '#0A2A48',
  blue800: '#004585',
  blue700: '#00529E',
  blue600: '#005FB8',
  blue500: '#006CD1',
  blue400: '#1785EB',
  blue300: '#5EA7EB',
  blue200: '#99CEFF',
  blue100: '#C7E4FF',
  blue50: '#EAF3FB',

  peach500: '#FCC79B',
  peach400: '#FAE0CB',
  peach50: '#FCF1E8',

  pink500: '#E365A6',
  pink400: '#FFDAED',
  pink50: '#FAEFF5',

  grey500: '#193652',
  grey400: '#3D556B',
  grey300: '#8FA1B3',
  grey200: '#D9E3ED',
  grey100: '#F2F5F7',
  grey50: '#F9FAFB',

  white: '#FFFFFF'
}

const textColors = {
  title: rawColors.grey500,
  body: rawColors.grey400,
  muted: rawColors.grey300,
  white: rawColors.white
}

const colors = {
  primary: rawColors.green500,
  dark: rawColors.blue900,
  borderColor: rawColors.grey200,
  activeColor: rawColors.blue500,

  backgroundTint1: rawColors.grey50,
  backgroundTint2: rawColors.grey100,

  white: rawColors.white,

  danger: rawColors.pink500,
  success: rawColors.green500,
  question: rawColors.blue500,
  warning: rawColors.peach500
}

const majorScale = x => `${x * 8}px`
const minorScale = x => `${x * 4}px`

/**
 * Preset sizes for input and button elements
 */

const controlSizes = {
  small: {
    minHeight: majorScale(4),
    minWidth: majorScale(4),
    textStyle: 'body2'
  },
  default: {
    minHeight: majorScale(5),
    minWidth: majorScale(5),
    textStyle: 'body1'
  }
}

const fonts = {}

fonts.sans = `'Segment Circular Std', 'Helvetica Neue', Helvetica, Arial, sans-serif`
fonts.serif = `'Segment Aleo', Georgia, serif`
fonts.mono = `'Droid Sans Mono', Monaco, 'Lucida Console', monospace`

const textStyles = {}

textStyles.display1 = {
  fontFamily: fonts.sans,
  fontSize: '22px',
  fontWeight: '400',
  lineHeight: majorScale(4),
  letterSpacing: '-0.67px'
}

textStyles.display2 = {
  fontFamily: fonts.sans,
  fontSize: '20px',
  fontWeight: '400',
  lineHeight: majorScale(4),
  letterSpacing: '-0.645px'
}

textStyles.display3 = {
  fontFamily: fonts.sans,
  fontSize: '18px',
  fontWeight: '400',
  lineHeight: majorScale(3),
  letterSpacing: '-0.31px'
}

textStyles.display4 = {
  fontFamily: fonts.sans,
  fontSize: '16px',
  fontWeight: '500',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.display5 = {
  fontFamily: fonts.sans,
  fontSize: '14px',
  fontWeight: '500',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.body1 = {
  // color: textColors.body,
  fontFamily: fonts.sans,
  fontSize: '14px',
  fontWeight: '400',
  lineHeight: majorScale(3),
  letterSpacing: '0'
}

textStyles.body2 = {
  fontFamily: fonts.sans,
  fontSize: '12px',
  fontWeight: '400',
  lineHeight: majorScale(2),
  letterSpacing: '0'
}

textStyles.mono = {
  fontFamily: fonts.mono,
  fontSize: '13px',
  fontWeight: '300',
  lineHeight: '21px',
  letterSpacing: '0'
}

textStyles.caps1 = {
  fontFamily: fonts.sans,
  fontSize: '12px',
  fontWeight: '500',
  lineHeight: majorScale(2),
  letterSpacing: '0.08em',
  textTransform: 'uppercase'
}

textStyles.caps2 = {
  fontFamily: fonts.sans,
  fontSize: '10px',
  fontWeight: '600',
  lineHeight: majorScale(2),
  letterSpacing: '0.08em',
  textTransform: 'uppercase'
}

const intent = {
  primary: {
    default: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    hover: {
      linkColor: Color(colors.primary).lighten(0.2).saturate(0.2).rgb().string(),
      backgroundColor: rawColors.green400,
      textColor: colors.white
    },
    active: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    focus: {
      linkColor: colors.primary,
      backgroundColor: rawColors.green400,
      textColor: colors.white
    }
  },
  secondary: {
    default: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      border: `1px solid ${colors.borderColor}`
    },
    hover: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      border: `1px solid ${Color(colors.borderColor).darken(0.2).rgb().string()}`
    },
    active: {
      linkColor: colors.activeColor,
      backgroundColor: colors.backgroundTint1,
      textColor: textColors.title,
      border: `1px solid ${Color(colors.borderColor).darken(0.3).rgb().string()}`
    },
    focus: {
      linkColor: colors.darkTint,
      backgroundColor: colors.white,
      textColor: textColors.body,
      border: `1px solid ${Color(colors.borderColor).darken(0.3).rgb().string()}`
    }
  },
  danger: {
    default: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: colors.white
    },
    hover: {
      linkColor: colors.danger,
      backgroundColor: Color(colors.danger).whiten(0.3).rgb().string(),
      textColor: textColors.white
    },
    active: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: textColors.white
    },
    focus: {
      linkColor: colors.danger,
      backgroundColor: [Color(colors.danger).whiten(0.3).rgb().string()],
      textColor: textColors.white
    }
  }
}

const controlStateStyles = {
  default: {
    backgroundColor: colors.white,
    color: textColors.body,
    border: `1px solid ${colors.borderColor}`
  },
  hover: {
    backgroundColor: rawColors.white,
    color: textColors.body,
    border: `1px solid ${Color(colors.borderColor).darken(0.1).rgb().string()}`
  },
  active: {
    backgroundColor: rawColors.grey100,
    color: textColors.body,
    border: `1px solid ${Color(colors.borderColor).darken(0.1).rgb().string()}`
  },
  checked: {
    backgroundColor: colors.activeColor,
    color: colors.white,
    border: `1px solid transparent`
  }
}

const backgrounds = {}

backgrounds.dark = {
  textColor: colors.white,
  backgroundColor: colors.dark,
  borderColor: colors.borderColor, // TODO: implement/think about dark borderColor
  borderColorInteractive: colors.borderColor
}

backgrounds.white = {
  textColor: textColors.body,
  backgroundColor: colors.white,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

backgrounds.tint1 = backgrounds.tint = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey50,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

backgrounds.tint2 = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey100,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
}

const animationEasing = {
  standard: `cubic-bezier(0.4, 0.0, 0.2, 1)`,
  deceleration: `cubic-bezier(0.0, 0.0, 0.2, 1)`,
  acceleration: `cubic-bezier(0.4, 0.0, 1, 1)`,
  sharp: `cubic-bezier(0.4, 0.0, 0.6, 1)`,
  spring: `cubic-bezier(0.175, 0.885, 0.320, 1.175)`
}

// https://material.io/guidelines/motion/duration-easing.html#duration-easing-common-durations
const animationDuration = {
  faster: `150ms`,
  fast: `225ms`,
  slow: `400ms`
}

const activeClassName = 'evergreen-active'

const theme = {
  activeClassName,
  majorScale,
  minorScale,
  animationEasing,
  animationDuration,
  rawColors,
  backgrounds,
  fonts,
  textColors,
  textStyles,
  colors,
  intent,
  controlStateStyles,
  controlSizes,
  borderRadius: ['5px', '8px'],
  popoverShadow: `0 2px 4px rgba(0,0,0,0.04), 0 8px 24px rgba(0,0,0,0.02)`,
  shadows: [
    '0 5px 15px -5px rgba(0,0,0,0.1)',
    '0 2px 4px 0 rgba(0,0,0,0.04)'
  ]
}

export default theme
